@@ -652,13 +652,13 @@ def get_string_length(string_file):
                         raise cdbError('ADrill Database {} not defined.'.format(cdb_name))
                 fid_tool = open(tool_file, 'r')
                 file_type = ''
-                for line in fid_tool:
-                    if file_type and 'top_drive' not in file_type.lower() and line.replace(' ', '').split('=')[0] in TO_LENGTH_PARAM[file_type] and not line.startswith('$'):
-                        tool_length = float(line.replace(' ', '').split('=')[1])
+                for tool_line in fid_tool:
+                    if file_type and 'top_drive' not in file_type.lower() and tool_line.replace(' ', '').split('=')[0] in TO_LENGTH_PARAM[file_type.lower()] and not tool_line.startswith('$'):
+                        tool_length = float(tool_line.replace(' ', '').split('=')[1])
                         tool_lengths.append(tool_length)
                         break
-                    elif ' file_type' in line.lower() and not line.startswith('$'):
-                        file_type = line.replace(' ', '').replace("'",'').replace('\n','').split('=')[1]
+                    elif ' file_type' in tool_line.lower() and not tool_line.startswith('$'):
+                        file_type = tool_line.replace(' ', '').replace("'",'').replace('\n','').split('=')[1]
                 fid_tool.close()
             if ' number_of_joints' in line.lower():
                 n = int(line.replace(' ','').split('=')[1])
@@ -872,7 +872,7 @@ def create_cfg_file(filename, database_paths):
         databases.append({'name': name, 'path': path})
 
     # Get the cfg template
-    cfg_template = env.get_template('template.cfg')
+    cfg_template = env.from_string(open(os.path.join(os.path.dirname(__file__), 'templates', 'template.cfg')).read())
     
     # Write the new cfg file
     with open(filename ,'w') as fid:
@@ -961,23 +961,42 @@ TO_TABLE_LINE_PATTERN = re.compile("^((\\s*\\'[_0-9a-zA-Z]+\\')+)|((\\s*-?[\\+-\
 def read_TO_file(filename):
     """Reads a Tiem Orbit file into a dictionary of parameters
     
+    Example
+    -------
+    This example prints the value of the `Integrator` parameter from the `DYNAMICS` block of a solver settings file.
+
+    >>> ssf = read_TO_file('example.ssf')
+    >>> integ = ssf['DYNAMICS']['Integrator']
+    >>> print(integ)
+    HHT
+
+    This example prints `Maxit` from the `FUNNEL` subblock of the `STATICS` block of a solver settings file.
+    
+    >>> ssf = adripy.read_TO_file('example.ssf')
+    >>> maxit = ssf['STATICS']['FUNNEL']['maxit']
+    >>> print(maxit)
+    [100, 50, 50, 50]
+
     Parameters
     ----------
     filename : str
         Filename of the Tiem Orbit file
+
+    Returns
+    -------
+    dict
+        Nested :obj:`dict` of the blocks, subblocks, and parameters.  
     
     Raises
     ------
     TiemOrbitSyntaxError
         Raised if the Tiem Orbit syntax is not recognized
-    """
-    filename = get_full_path(os.path.normpath(filename))
-    
-    if not os.path.exists(filename):
+    """    
+    if not os.path.exists(get_full_path(os.path.normpath(filename))):
         raise FileNotFoundError(f'{filename} does not exist!')
     
     # Read in the TO file
-    with open(filename, 'r') as fid:
+    with open(get_full_path(filename), 'r') as fid:
         lines = fid.readlines()    
 
     current_block = None
@@ -985,6 +1004,7 @@ def read_TO_file(filename):
     current_table_headers = []
     current_table_data = {}
     parameters = {}
+
     for line in lines:
         # For each line determine if we are at a new Block, new SubBlock, or Table
         
@@ -1013,6 +1033,13 @@ def read_TO_file(filename):
             
             # Make a dictionary of empty lists to put the table data in
             current_table_data = {header: [] for header in current_table_headers}
+
+            # Add empty table data to parameters dictionary
+            for header in current_table_headers:
+                if current_subblock is not None:
+                    parameters[current_block][current_subblock][header.lower()] = []
+                else:
+                    parameters[current_block][header.lower()] = []
         
         elif TO_PARAMETER_PATTERN.match(line):            
             [parameter, value] = re.sub('[\\s\\n]','',line).split('=')
@@ -1060,8 +1087,149 @@ def read_TO_file(filename):
 
     return parameters
 
+def isabs(filename):
+    """Checks if a filepath is absolute.
+
+    Note
+    ----
+    This function is derived from :meth:`os.path.isabs`.  The only difference is that it returns `True` if the filepth uses cdb alias names.
+    
+    Parameters
+    ----------
+    filename : str
+        Path to a file.  Can be relateive, absolute, or use cdb aliases. 
+    
+    Returns
+    -------
+    bool
+        True if path is absolute or uses cdb aliases.
+
+    """    
+    if not isinstance(filename, str):
+        # If filname is not a string
+        is_abs = False
+
+    elif filename != get_full_path(filename):
+        # If filename uses cdb alias notation
+        is_abs = True
+
+    elif os.path.isabs(filename):
+        # If filename is an absolute path
+        is_abs = True
+
+    else:
+        # If filename is a relative
+        is_abs = False
+    
+    return is_abs
+            
+def add_splines_to_adm(adm_file, splines):
+    """Adds splines inputs to an Adams Drill dataset (.adm) file.
+    
+    Adds a block titled SPLINES above the OUTPUT block of the ADM file.  The SPLINES block contains a SPLINE statement for each of the four drilling parameters.
+
+    Example
+    -------
+    >>> time = [0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0]
+    >>> gpm = [0, 78.125, 250.0, 421.875, 500, 500, 500, 500, 500, 500, 500]
+    >>> rpm = [0, 0, 0, 0, 12, 37, 50, 50, 50, 50, 50]
+    >>> wob = [0, 0, 0, 0, 0, 0, 0, 10, 29, 40, 40]
+    >>> rop = [0, 0, 0, 0, 0, 0, 0, 25, 74, 100, 100]
+    >>> splines = {}
+    >>> splines['gpm'] = [time, gpm]
+    >>> splines['rpm'] = [time, rpm]
+    >>> splines['wob'] = [time, wob]
+    >>> splines['rop'] = [time, rop]
+    >>> adm_file = 'demo.adm'
+    >>> add_splines_to_adm(adm_file, splines)    
+
+    Parameters
+    ----------
+    adm_file : str
+        Filename of Adams Drill dataset (.adm) file
+    splines : dict
+        Dictionary containing the spline data for the four drilling parameters.  See Example for dictionary makeup.
+    
+    """
+    code_block = {}
+    input_params = ['ROP','WOB','RPM','GPM']
+    for i, param in enumerate(input_params):
+        code_block[param] = "!\n"
+        code_block[param] += "!                          adams_view_name='{}_Spline'\n".format(param)
+        code_block[param] += "SPLINE/1000{}\n".format(i)
+        code_block[param] += ", LINEAR_EXTRAPOLATE\n"
+        code_block[param] += ", X={}\n".format(str(splines[param.lower()][1]).replace('[','').replace(']',''))
+        
+        val_string = ''
+        for val in splines[param.lower()][0]:
+            val_string += '{:1.2f},'.format(val)
+        val_string = val_string[:-1]
+        code_block[param] += ", Y={}\n".format(val_string)
+        
+    
+    with open(adm_file, 'r') as fid, open(adm_file.replace('.adm','.tmp'),'w') as fid_new:
+        insert_splines_here = False
+        for line in fid:
+            if insert_splines_here:
+                fid_new.write('!----------------------------------- SPLINES ------------------------------------\n')
+                for param in code_block:
+                    fid_new.write(code_block[param])
+                fid_new.write("!\n")
+                fid_new.write("!----------------------------------- OUTPUT ------------------------------------\n")
+                fid_new.write("!\n")
+                insert_splines_here = False
+            elif '!----------------------------------- OUTPUT ------------------------------------' in line:
+                insert_splines_here = True
+            else:
+                fid_new.write(line)        
+    os.remove(adm_file)
+    os.rename(adm_file.replace('.adm','.tmp'), adm_file)
+
+def add_splines_to_acf(acf_file):   
+
+    # go through original acf and create a new acf
+    with open(acf_file,'r') as fid, open(acf_file.replace('.acf','.tmp'),'w') as fid_new:
+        
+        modify = False
+        skip = False
+        variable_id = 0
+
+        for line in fid:
+            # For each line in the original acf file
+
+            if modify:
+                # If this is a line defining a drilling parameter
+                if variable_id == 1102:
+                    new_line = ', FUNCTION = STEP(TIME, 0,0,1,1)*VARVAL(11021)*ABS(AKISPL(TIME,0,10003, 0))\n'
+                    skip = True
+                elif variable_id == 9104:
+                    new_line = ', FUNCTION = STEP(TIME, 0,0,1,1)*(AKISPL(TIME,0,10000, 0))/3600\n'
+                elif variable_id == 9105:
+                    new_line = ', FUNCTION = STEP(TIME, 0,0,1,1)*(AKISPL(TIME,0,10002, 0))*(PI/30)\n'
+                elif variable_id == 9106:
+                    new_line = ', FUNCTION = STEP(TIME, 0,0,1,1)*(AKISPL(TIME,0,10001, 0))*1000\n'
+                fid_new.write(new_line)
+                modify = False
+            
+            elif skip:
+                # If this is a line that should be skipped
+                skip = False
+                if line.startswith('!'):
+                    fid_new.write(line)                        
+            
+            else:
+                # If this is a normal line
+                fid_new.write(line)
+                if 'VARIABLE' in line:
+                    variable_id = int(line.split('/')[1].replace('&','').replace(' ',''))
+                    modify = True
+    
+    # Replace original acf file
+    os.remove(acf_file)
+    os.rename(acf_file.replace('.acf','.tmp'), acf_file)
+
 class TiemOrbitSyntaxError(Exception):
     pass
 
 class cdbError(Exception):
-    pass
+    pass
\ No newline at end of file
